@@ -183,7 +183,7 @@ class Generator:
         exp.WithJournalTableProperty: exp.Properties.Location.POST_NAME,
     }
 
-    WITH_SEPARATED_COMMENTS = (exp.Select, exp.From, exp.Where, exp.Binary)
+    WITH_SEPARATED_COMMENTS = (exp.Select, exp.From, exp.Where)
     SENTINEL_LINE_BREAK = "__SQLGLOT__LB__"
 
     __slots__ = (
@@ -322,10 +322,15 @@ class Generator:
         comment = comment + " " if comment[-1].strip() else comment
         return comment
 
-    def maybe_comment(self, sql: str, expression: exp.Expression) -> str:
-        comments = expression.comments if self._comments else None
+    def maybe_comment(
+        self,
+        sql: str,
+        expression: t.Optional[exp.Expression] = None,
+        comments: t.Optional[t.List[str]] = None,
+    ) -> str:
+        comments = (comments or (expression and expression.comments)) if self._comments else None  # type: ignore
 
-        if not comments:
+        if not comments or isinstance(expression, exp.Binary):
             return sql
 
         sep = "\n" if self.pretty else " "
@@ -730,7 +735,10 @@ class Generator:
         materialized = " MATERIALIZED" if expression.args.get("materialized") else ""
         cascade = " CASCADE" if expression.args.get("cascade") else ""
         constraints = " CONSTRAINTS" if expression.args.get("constraints") else ""
-        return f"DROP{temporary}{materialized} {kind}{exists_sql}{this}{cascade}{constraints}"
+        purge = " PURGE" if expression.args.get("purge") else ""
+        return (
+            f"DROP{temporary}{materialized} {kind}{exists_sql}{this}{cascade}{constraints}{purge}"
+        )
 
     def except_sql(self, expression: exp.Except) -> str:
         return self.prepend_ctes(
@@ -772,6 +780,13 @@ class Generator:
             text = f"{self.identifier_start}{text}{self.identifier_end}"
         return text
 
+    def inputoutputformat_sql(self, expression: exp.InputOutputFormat) -> str:
+        input_format = self.sql(expression, "input_format")
+        input_format = f"INPUTFORMAT {input_format}" if input_format else ""
+        output_format = self.sql(expression, "output_format")
+        output_format = f"OUTPUTFORMAT {output_format}" if output_format else ""
+        return self.sep().join((input_format, output_format))
+
     def national_sql(self, expression: exp.National) -> str:
         return f"N{self.sql(expression, 'this')}"
 
@@ -1712,7 +1727,11 @@ class Generator:
         if not self.pretty:
             return self.binary(expression, op)
 
-        sqls = tuple(self.sql(e) for e in expression.flatten(unnest=False))
+        sqls = tuple(
+            self.maybe_comment(self.sql(e), e, e.parent.comments) if i != 1 else self.sql(e)
+            for i, e in enumerate(expression.flatten(unnest=False))
+        )
+
         sep = "\n" if self.text_width(sqls) > self._max_text_width else " "
         return f"{sep}{op} ".join(sqls)
 
@@ -1935,6 +1954,7 @@ class Generator:
         return f"USE{kind}{this}"
 
     def binary(self, expression: exp.Binary, op: str) -> str:
+        op = self.maybe_comment(op, comments=expression.comments)
         return f"{self.sql(expression, 'this')} {op} {self.sql(expression, 'expression')}"
 
     def function_fallback_sql(self, expression: exp.Func) -> str:
